==> tortoise-orm-0.15.3.tar.gz: tortoise-orm-0.15.3/tortoise/backends/sqlite/executor.py <==
import datetime
from decimal import Decimal
from typing import Optional

from pypika import Parameter

from tortoise import Model, fields
from tortoise.backends.base.executor import BaseExecutor
from tortoise.fields import BigIntField, IntField, SmallIntField


def to_db_bool(self, value, instance) -> Optional[int]:
    if value is None:
        return None
    return int(bool(value))


def to_db_decimal(self, value, instance) -> Optional[str]:
    if value is None:
        return None
    if self.decimal_places == 0:
        quant = "1"
    else:
        quant = f"1.{('0' * self.decimal_places)}"
    return str(Decimal(value).quantize(Decimal(quant)).normalize())


def to_db_datetime(self, value: Optional[datetime.datetime], instance) -> Optional[str]:
    if hasattr(instance, "_saved_in_db"):
        # Only do this if it is a Model instance, not class. Test for guaranteed instance var
        if self.auto_now:
            value = datetime.datetime.utcnow()
            setattr(instance, self.model_field_name, value)
            return value.isoformat(" ")
        if self.auto_now_add and getattr(instance, self.model_field_name, None) is None:
            value = datetime.datetime.utcnow()
            setattr(instance, self.model_field_name, value)
            return value.isoformat(" ")
    if isinstance(value, datetime.datetime):
        return value.isoformat(" ")
    return None


class SqliteExecutor(BaseExecutor):
    TO_DB_OVERRIDE = {
        fields.BooleanField: to_db_bool,
        fields.DecimalField: to_db_decimal,
        fields.DatetimeField: to_db_datetime,
    }
    EXPLAIN_PREFIX = "EXPLAIN QUERY PLAN"
    DB_NATIVE = {str, int, bool, float}

    def Parameter(self, pos: int) -> Parameter:
        return Parameter("?")

    async def _process_insert_result(self, instance: Model, results: int):
        pk_field_object = self.model._meta.pk
        if (
            isinstance(pk_field_object, (SmallIntField, IntField, BigIntField))
            and pk_field_object.generated
        ):
            instance.pk = results

        # SQLite can only generate a single ROWID
        #   so if any other primary key, it won't generate what we want.

==> tortoise-orm-0.15.5.tar.gz: tortoise-orm-0.15.5/tortoise/backends/sqlite/executor.py <==
import datetime
from decimal import Decimal
from typing import Optional

from pypika import Parameter

from tortoise import Model, fields
from tortoise.backends.base.executor import BaseExecutor
from tortoise.fields import BigIntField, IntField, SmallIntField


def to_db_bool(self, value, instance) -> Optional[int]:
    if value is None:
        return None
    return int(bool(value))


def to_db_decimal(self, value, instance) -> Optional[str]:
    if value is None:
        return None
    return str(Decimal(value).quantize(self.quant).normalize())


def to_db_datetime(self, value: Optional[datetime.datetime], instance) -> Optional[str]:
    if hasattr(instance, "_saved_in_db"):
        # Only do this if it is a Model instance, not class. Test for guaranteed instance var
        if self.auto_now or (
            self.auto_now_add and getattr(instance, self.model_field_name, None) is None
        ):
            value = datetime.datetime.utcnow()
            setattr(instance, self.model_field_name, value)
            return value.isoformat(" ")
    if isinstance(value, datetime.datetime):
        return value.isoformat(" ")
    return None


class SqliteExecutor(BaseExecutor):
    TO_DB_OVERRIDE = {
        fields.BooleanField: to_db_bool,
        fields.DecimalField: to_db_decimal,
        fields.DatetimeField: to_db_datetime,
    }
    EXPLAIN_PREFIX = "EXPLAIN QUERY PLAN"
    DB_NATIVE = {str, int, bool, float}

    def Parameter(self, pos: int) -> Parameter:
        return Parameter("?")

    async def _process_insert_result(self, instance: Model, results: int):
        pk_field_object = self.model._meta.pk
        if (
            isinstance(pk_field_object, (SmallIntField, IntField, BigIntField))
            and pk_field_object.generated
        ):
            instance.pk = results

        # SQLite can only generate a single ROWID
        #   so if any other primary key, it won't generate what we want.
